#
# Fedora spec file for php-gitter
#
# Copyright (c) 2014-2017 Shawn Iwinski <shawn.iwinski@gmail.com>
#
# License: MIT
# http://opensource.org/licenses/MIT
#
# Please preserve changelog entries
#

%global github_owner     klaussilveira
%global github_name      gitter
%global github_version   0.3.0
%global github_commit    6eff42830c336ee9b8b8b9d2f69b62bd9bcbaf3b

%global composer_vendor  klaussilveira
%global composer_project gitter

# "php": ">=5.3.0"
%global php_min_ver 5.3.0
# "symfony/process": ">=2.2"
# "symfony/filesystem": ">=2.2"
#     NOTE: Min version not 2.2 because autoloader required
%global symfony_min_ver %{?el6:2.3.31}%{!?el6:2.7.1}
%global symfony_max_ver 3.0
# "mockery/mockery": "0.9.1"
%global mockery_min_ver 0.9.1
%global mockery_max_ver 1.0


# Build using "--without tests" to disable tests
%global with_tests 0%{!?_without_tests:1}

%{!?phpdir:  %global phpdir  %{_datadir}/php}

Name:          php-%{composer_project}
Version:       %{github_version}
Release:       8%{?github_release}%{?dist}
Summary:       Object oriented interaction with Git repositories

Group:         Development/Libraries
License:       BSD
URL:           https://github.com/%{github_owner}/%{github_name}
Source0:       %{url}/archive/%{github_commit}/%{name}-%{github_version}-%{github_commit}.tar.gz

# fix for git 2.4.x
# https://github.com/klaussilveira/gitter/pull/47
Patch0:        %{name}-pr47.patch

BuildArch:     noarch
# Tests
%if %{with_tests}
BuildRequires: git
## composer.json
BuildRequires: php(language) >= %{php_min_ver}
%if 0%{?el6}
BuildRequires: php-deepend-Mockery <  %{mockery_max_ver}
BuildRequires: php-deepend-Mockery >= %{mockery_min_ver}
%else
BuildRequires: php-composer(mockery/mockery) <  %{mockery_max_ver}
BuildRequires: php-composer(mockery/mockery) >= %{mockery_min_ver}
%endif
BuildRequires: php-composer(phpunit/phpunit)
BuildRequires: php-composer(symfony/filesystem) < %{symfony_max_ver}
BuildRequires: php-composer(symfony/filesystem) >= %{symfony_min_ver}
BuildRequires: php-composer(symfony/process) < %{symfony_max_ver}
BuildRequires: php-composer(symfony/process) >= %{symfony_min_ver}
## phpcompatinfo (computed from version 0.3.0)
BuildRequires: php-date
BuildRequires: php-pcre
BuildRequires: php-reflection
BuildRequires: php-spl
## Autoloader
BuildRequires: php-composer(fedora/autoloader)
%endif

Requires:      git
# composer.json
Requires:      php(language) >= %{php_min_ver}
Requires:      php-composer(symfony/process) >= %{symfony_min_ver}
Requires:      php-composer(symfony/process) <  %{symfony_max_ver}
# phpcompatinfo (computed from version 0.3.0)
Requires:      php-date
Requires:      php-pcre
Requires:      php-reflection
Requires:      php-spl
# Autoloader
Requires:      php-composer(fedora/autoloader)

# Standard "php-{COMPOSER_VENDOR}-{COMPOSER_PROJECT}" naming
Provides:      php-%{composer_vendor}-%{composer_project} = %{version}-%{release}
# Composer
Provides:      php-composer(%{composer_vendor}/%{composer_project}) = %{version}

%description
Gitter allows you to interact in an object oriented manner with Git repositories
via PHP. The main goal of the library is not to replace the system git command,
but provide a coherent, stable and performatic object oriented interface.

Most commands are sent to the system's git command, parsed and then interpreted
by Gitter. Everything is transparent to you, so you don't have to worry about a
thing.

Autoloader: %{phpdir}/Gitter/autoload.php


%prep
%setup -qn %{github_name}-%{github_commit}

: fix for git 2.4.x
: https://github.com/klaussilveira/gitter/pull/47
%patch0 -p1


%build

: Create autoloader
cat <<'AUTOLOAD' | tee lib/Gitter/autoload.php
<?php
/**
 * Autoloader for %{name} and its' dependencies
 * (created by %{name}-%{version}-%{release}).
 */
require_once '%{phpdir}/Fedora/Autoloader/autoload.php';

\Fedora\Autoloader\Autoload::addPsr4('Gitter\\', __DIR__);

\Fedora\Autoloader\Dependencies::required(array(
    '%{phpdir}/Symfony/Component/Process/autoload.php',
));
AUTOLOAD


%install
mkdir -p %{buildroot}/%{phpdir}
cp -rp lib/* %{buildroot}/%{phpdir}/


%check
%if %{with_tests}
: Create tests bootstrap
cat <<'BOOTSTRAP' | tee bootstrap.php
<?php
require_once '%{buildroot}%{phpdir}/Gitter/autoload.php';

\Fedora\Autoloader\Dependencies::required(array(
    '%{phpdir}/Mockery/autoload.php',
    '%{phpdir}/Symfony/Component/Filesystem/autoload.php',
));
BOOTSTRAP

: Always run all tests
sed '/stopOnFailure/d' phpunit.xml.dist > phpunit.xml

: Upstream tests
RETURN_CODE=0
PHPUNIT=$(which phpunit)
for PHP_EXEC in "" %{?rhel:php54 php55} php56 php70 php71 php72; do
    if [ -z "$PHP_EXEC" ] || which $PHP_EXEC; then
        $PHP_EXEC $PHPUNIT --verbose --bootstrap bootstrap.php \
            || RETURN_CODE=1
    fi
done
exit $RETURN_CODE
%else
: Tests skipped
%endif


%files
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc *.md
%doc composer.json
%{phpdir}/Gitter


%changelog
* Sun May 14 2017 Shawn Iwinski <shawn.iwinski@gmail.com> - 0.3.0-8
- Switch autoloader to php-composer(fedora/autoloader)
- Add max versions to build dependencies
- Test with SCLs if available

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0.3.0-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0.3.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sat Jul 11 2015 Shawn Iwinski <shawn.iwinski@gmail.com> - 0.3.0-5
- Use full require paths in autoloader

* Sat Jul 11 2015 Shawn Iwinski <shawn.iwinski@gmail.com> - 0.3.0-4
- Added autoloader
- Added standard "php-{COMPOSER_VENDOR}-{COMPOSER_PROJECT}" naming provides

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.3.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sun May 24 2015 Remi Collet <remi@fedoraproject.org> - 0.3.0-2
- add patch for git 2.4 (FTBFS detected by Koschei)

* Sat Jul 19 2014 Shawn Iwinski <shawn.iwinski@gmail.com> - 0.3.0-1
- Updated to 0.3.0 (BZ #1101229)
- Added "php-composer(klaussilveira/gitter)" virtual provide
- Added option to build without tests ("--without tests")

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.2.0-3.20131206git786e86a
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Thu Feb 20 2014 Shawn Iwinski <shawn.iwinski@gmail.com> - 0.2.0-2.20131206git786e86a
- Conditional release dist

* Mon Jan 27 2014 Shawn Iwinski <shawn.iwinski@gmail.com> - 0.2.0-1.20131206git786e86a
- Initial package
